/***************************************************************************
 *            xesam-g-utils.c
 *
 *  Thu Jul 26 21:22:10 2007
 *  Copyright  2007  Mikkel Kamstrup Erlandsen
 *  <mikkel.kamstrup@gmail.com>
 ****************************************************************************/

/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with main.c; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

#include "xesam-g-utils.h"

/*
 * Initialize a value if it points to NULL
 */
GValue*
init_value_if_null (GValue **value, GType value_type)
{
    if (*value == NULL) {
        *value = g_new0 (GValue, 1);
        g_value_init (*value, value_type);
    }
    
    return *value;
        
}

/**
 * xesam_g_clone_value
 * @orig: %GValue to clone
 *
 * Return value: A newly allocated and initialized %GValue with a copy of the
 *               contents of @orig.
 */
GValue*
xesam_g_clone_value (const GValue *orig)
{
	GValue  *clone;
	
	clone = g_new0 (GValue, 1);
	g_value_init (clone, G_VALUE_TYPE(orig));
	g_value_copy (orig, clone);
	
	return clone;
}

/**
 * g_property_to_xesam_property
 * @g_prop_name: A string formatted as a standard GObject property (or signal)
 *               delimited by '_' or '-'.
 *
 * Return value: A newly allocated string with '-' and '_'
 * converted to '.'. Primarily for computing xesam session property
 * names from gobject property names.
 */
gchar*
g_property_to_xesam_property (gchar *g_prop_name)
{
    gchar *prop_name;
    
    prop_name = g_strdup (g_prop_name);
	g_strdelimit (prop_name, "-_", '.');
    
    return prop_name;
}

static void
_free_value_func (GValue *value, gpointer data) {
    g_value_unset (value);
    g_free (value);
}

void
free_ptr_array_of_values (GPtrArray *array)
{
    g_ptr_array_foreach (array, (GFunc)_free_value_func, NULL);
    g_ptr_array_free (array, TRUE);
}

const gchar*
digit_as_const_char (guint			digit)
{
	switch (digit) {
		case 0 : return "0";
		case 1 : return "1";
		case 2 : return "2";
		case 3 : return "3";
		case 4 : return "4";
		case 5 : return "5";
		case 6 : return "6";
		case 7 : return "7";
		case 8 : return "8";
		case 9 : return "9";
		default :
			g_warning ("Not a digit '%d'", digit);
			return "0";
	}
}

GQuark
xesam_g_error_quark (void)
{
  return g_quark_from_static_string ("xesam-g-error-quark");
}
